@@ -125,7 +125,6 @@ link_public_api(FILE *)
 typedef enum
 {
 	VDAL=1, /* Sort by Violations, Disjunct cost, Link cost */
-	CORPUS, /* Sort by Corpus cost */
 } Cost_Model_type;
 
 typedef struct Parse_Options_s * Parse_Options;
@@ -200,10 +199,6 @@ link_public_api(bool)
      parse_options_memory_exhausted(Parse_Options opts);
 link_public_api(bool)
      parse_options_resources_exhausted(Parse_Options opts);
-link_public_api(void)
-     parse_options_set_use_cluster_disjuncts(Parse_Options opts, bool val);
-link_public_api(bool)
-     parse_options_get_use_cluster_disjuncts(Parse_Options opts);
 link_public_api(void)
      parse_options_set_all_short_connectors(Parse_Options opts, bool val);
 link_public_api(bool)
@@ -215,6 +210,10 @@ link_public_api(bool)
 link_public_api(void)
      parse_options_reset_resources(Parse_Options opts);
 
+link_public_api(char *)
+	  parse_options_get_dialect(Parse_Options opts);
+link_public_api(void)
+	  parse_options_set_dialect(Parse_Options opts, const char *dialect);
 
 /**********************************************************************
  *
@@ -321,8 +320,6 @@ link_public_api(const char *)
      linkage_get_disjunct_str(const Linkage linkage, WordIdx word_num);
 link_public_api(double)
      linkage_get_disjunct_cost(const Linkage linkage, WordIdx word_num);
-link_public_api(double)
-     linkage_get_disjunct_corpus_score(const Linkage linkage, WordIdx word_num);
 link_public_api(const char *)
      linkage_get_word(const Linkage linkage, WordIdx word_num);
 link_public_api(char *)
@@ -349,32 +346,25 @@ link_public_api(char *)
      linkage_print_pp_msgs(Linkage linkage);
 link_public_api(void)
      linkage_free_pp_msgs(char * str);
-link_public_api(char *)
-     linkage_print_senses(Linkage linkage);
-link_public_api(void)
-     linkage_free_senses(char *str);
 link_public_api(int)
      linkage_unused_word_cost(const Linkage linkage);
 link_public_api(double)
      linkage_disjunct_cost(const Linkage linkage);
 link_public_api(int)
      linkage_link_cost(const Linkage linkage);
-link_public_api(double)
-     linkage_corpus_cost(const Linkage linkage);
 link_public_api(const char *)
      linkage_get_violation_name(const Linkage linkage);
 
 /* Experimental API - subject to changes. */
-link_public_api(size_t)
+link_public_api(WordIdx)
      linkage_get_word_byte_start(const Linkage linkage, WordIdx w);
-link_public_api(size_t)
+link_public_api(WordIdx)
      linkage_get_word_byte_end(const Linkage linkage, WordIdx w);
-link_public_api(size_t)
+link_public_api(WordIdx)
      linkage_get_word_char_start(const Linkage linkage, WordIdx w);
-link_public_api(size_t)
+link_public_api(WordIdx)
      linkage_get_word_char_end(const Linkage linkage, WordIdx w);
 
-
 /**********************************************************************
  *
  * Internal functions -- do not use these in new code!
@@ -390,8 +380,6 @@ link_public_api(char *)
      dict_display_word_expr(Dictionary dict, const char *, Parse_Options opts);
 link_public_api(char *)
      dict_display_word_info(Dictionary dict, const char *, Parse_Options opts);
-link_public_api(bool)
-     lg_expand_disjunct_list(Sentence sent);
 
 /**********************************************************************
  *
